==> haskell-hspec-discover-2.10.9-51.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.10.9
visibility:           public
id:                   hspec-discover-2.10.9-LUkZf9Lqnwt9WGENwHN2BB
key:                  hspec-discover-2.10.9-LUkZf9Lqnwt9WGENwHN2BB
license:              MIT
copyright:            (c) 2012-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <https://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  92cda00d1e9ef23b1111b82dc06013ff
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-discover-2.10.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-discover-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.10.9-LUkZf9Lqnwt9WGENwHN2BB
depends:              base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.10.9-55.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-discover
version:              2.10.9
visibility:           public
id:                   hspec-discover-2.10.9-5Raukkb2PEP7FOCSGQ7nrF
key:                  hspec-discover-2.10.9-5Raukkb2PEP7FOCSGQ7nrF
license:              MIT
copyright:            (c) 2012-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <https://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  3fcfe74908ba891aab831b09548e7f9a
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-discover-2.10.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-discover-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.10.9-5Raukkb2PEP7FOCSGQ7nrF
depends:              base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
